%bcond_with bootstrap

%global __provides_exclude_from ^%{_libdir}/sane/.*\.so.*$
%global __requires_exclude ^libsane-.*\.so\.[0-9]*(\(\).*)?+$
%global _docdocdir %{_docdir}/%{name}-doc

Summary:       Scanner access software
Name:          sane-backends
Version:       1.1.1
Release:       8%{?dist}
License:       GPLv2+ and GPLv2+ with exceptions and Public Domain and IJG and LGPLv2+ and MIT
URL:           http://www.sane-project.org
Source0:       https://gitlab.com/sane-project/backends/uploads/104f09c07d35519cc8e72e604f11643f/%{name}-%{version}.tar.gz
Source1:       sane.png
Source2:       saned.socket
Source3:       saned@.service.in
Source4:       66-saned.rules
Source5:       sane-backends.sysusers
Patch0001:     fixed-CVE-2023-46047.patch
Patch0002:     fixed-CVE-2023-46052.patch
Patch3000:     sane-backends-1.0.25-udev.patch
Patch3001:     sane-backends-1.0.23-soname.patch
Patch3002:     sane-backends-1.0.23-sane-config-multilib.patch
Patch3003:     sane-genesys-gl845-crash.patch
Patch3004:     sane-backends-pkgconfig-misunderstanding.patch


BuildRequires: gcc gcc-c++ make autoconf gettext
BuildRequires: gphoto2-devel libieee1284-devel
BuildRequires: libjpeg-devel libpng-devel libtiff-devel
BuildRequires: libusbx-devel libv4l-devel
BuildRequires: python3 systemd systemd-devel systemd-rpm-macros
Requires:      libpng systemd >= 196 systemd-udev >= 196
Requires:      sane-backends-libs = %{version}-%{release}
# sane-airscan buildrequires sane-backends-devel, sane-backends-devel requires sane-airscan
%if ! %{with bootstrap}
Requires:      sane-airscan
%endif
Suggests:      libnsl

%description
Scanner Access Now Easy (SANE) is a universal scanner interface.
The SANE application programming interface (API) provides standardized
access to any raster image scanner hardware (flatbed scanner,
hand-held scanner, video and still cameras, frame-grabbers, etc.).


%package doc
Summary:        SANE backends documentation
BuildArch:      noarch

%description doc
This package contains documentation for SANE backends.


%package libs
Summary:        SANE libraries
Recommends:     %{name}-drivers-cameras = %{version}-%{release}
Recommends:     %{name}-drivers-scanners = %{version}-%{release}

%description libs
This package contains the SANE libraries which are needed by applications that
want to access scanners.


%package devel
Summary:       SANE development toolkit
Requires:      pkgconfig
Requires:      libieee1284-devel
Requires:      libjpeg-devel libtiff-devel libusbx-devel
Requires:      sane-backends = %{version}-%{release}
Requires:      sane-backends-libs = %{version}-%{release}
Requires:      sane-backends-drivers-scanners = %{version}-%{release}
Requires:      sane-backends-drivers-cameras = %{version}-%{release}

%description devel
This package contains libraries and header files for writing Scanner Access
Now Easy (SANE) modules.


%package drivers-scanners
Summary:       SANE backend drivers for scanners
BuildRequires: libxml2-devel
Requires:      sane-backends = %{version}-%{release}
Requires:      sane-backends-libs = %{version}-%{release}

%description drivers-scanners
This package contains backend drivers to access scanner hardware through SANE.


%package drivers-cameras
Summary:       Scanner backend drivers for digital cameras
Requires:      sane-backends = %{version}-%{release}
Requires:      sane-backends-libs = %{version}-%{release}

%description drivers-cameras
This package contains backend drivers to access digital cameras through SANE.


%package daemon
Summary:       Scanner network daemon
Requires:      sane-backends = %{version}-%{release}
Requires:      sane-backends-libs = %{version}-%{release}

%description daemon
This package contains saned which is the daemon that allows remote clients to
access image acquisition devices available on the local host.


%prep
%autosetup -p1


%build
CFLAGS="%optflags -fno-strict-aliasing -fPIC"
%configure \
    --with-gphoto2=%{_prefix} \
    --with-docdir=%{_pkgdocdir} \
    --with-systemd --with-usb \
    --disable-locking --disable-rpath \
    --enable-pthread
%make_build

_topdir="$PWD"
pushd tools
./sane-desc -m udev+hwdb -s "${_topdir}/doc/descriptions:${_topdir}/doc/descriptions-external" -d0 > udev/sane-backends.rules
./sane-desc -m hwdb -s "${_topdir}/doc/descriptions:${_topdir}/doc/descriptions-external" -d0 > udev/sane-backends.hwdb
popd


%install
%make_install
install -p -D -m 0644 %{SOURCE5} %{buildroot}%{_sysusersdir}/sane-backends.conf
install -d %{buildroot}%{_datadir}/pixmaps
install -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps
rm -f %{buildroot}%{_bindir}/gamma4scanimage
rm -f %{buildroot}%{_mandir}/man1/gamma4scanimage.1*
find %{buildroot}%{_libdir} -name "*.a" -delete
find %{buildroot}%{_libdir} -name "*.la" -delete

install -p -D -m 0644 tools/udev/sane-backends.rules %{buildroot}%{_udevrulesdir}/65-sane-backends.rules
install -p -D -m 0644 tools/udev/sane-backends.hwdb %{buildroot}%{_udevhwdbdir}/20-sane-backends.hwdb
install -p -D -m 0644 %{SOURCE4} %{buildroot}%{_udevrulesdir}/66-saned.rules

install -d %{buildroot}%{_libdir}/pkgconfig
install -m 0644 tools/sane-backends.pc %{buildroot}%{_libdir}/pkgconfig/

mkdir %{buildroot}%{_docdocdir}
pushd %{buildroot}%{_pkgdocdir}
for f in *; do
    if [ -d "$f" ]; then
        mv "$f" "%{buildroot}%{_docdocdir}/${f}"
    else
        case "$f" in
        AUTHORS|ChangeLog|COPYING|LICENSE|NEWS|PROBLEMS|README|README.linux)
            ;;
        backend-writing.txt|PROJECTS|sane-*.html)
            mv "$f" "%{buildroot}%{_docdocdir}/${f}"
            ;;
        *)
            rm -rf "$f"
            ;;
        esac
    fi
done
popd


install -m 0755 -d %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}
sed 's|@CONFIGDIR@|%{_sysconfdir}/sane.d|g' < %{SOURCE3} > saned@.service
install -m 0644 saned@.service %{buildroot}%{_unitdir}

%find_lang %name


%post
udevadm hwdb --update >/dev/null 2>&1 || :

autodiscovery=`%{_bindir}/grep -E '^[[:space:]]*net[[:space:]]*autodiscovery' /etc/sane.d/epsonds.conf`
if [ -n "$autodiscovery" ]
then
  %{_bindir}/sed -i 's,^[[:space:]]*net[[:space:]]*autodiscovery,#net autodiscovery,g' /etc/sane.d/epsonds.conf
fi

%postun
udevadm hwdb --update >/dev/null 2>&1 || :

%pre daemon
%sysusers_create_compat %{SOURCE5}

%post daemon
%systemd_post saned.socket

%preun daemon
%systemd_preun saned.socket

%postun daemon
%systemd_postun_with_restart saned.socket


%files -f %{name}.lang
%license %{_pkgdocdir}/COPYING
%license %{_pkgdocdir}/LICENSE
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/{AUTHORS,ChangeLog,NEWS,PROBLEMS,README*}
%dir %{_sysconfdir}/sane.d
%dir %{_sysconfdir}/sane.d/dll.d
%exclude %config(noreplace) %{_sysconfdir}/sane.d/saned.conf
%exclude %config(noreplace) %{_sysconfdir}/sane.d/epsonds.conf
%config(noreplace) %{_sysconfdir}/sane.d/*.conf
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/sane.d/epsonds.conf
%{_udevrulesdir}/65-sane-backends.rules
%{_udevhwdbdir}/20-sane-backends.hwdb
%{_datadir}/pixmaps/sane.png
%dir %{_datadir}/sane
%dir %{_libdir}/sane
%{_bindir}/sane-find-scanner
%{_bindir}/scanimage
%{_bindir}/umax_pp

%exclude %{_mandir}/man1/sane-config.1*
%exclude %{_mandir}/man8/saned*
%{_mandir}/*/*



%files doc
%doc %{_docdocdir}


%files libs
%{_libdir}/libsane.so.1
%{_libdir}/libsane.so.1.1.1


%files devel
%{_bindir}/sane-config
%{_includedir}/sane
%{_libdir}/libsane.so
%{_libdir}/pkgconfig/sane-backends.pc
%{_mandir}/man1/sane-config.1*


%files drivers-scanners
%{_libdir}/sane/libsane-abaton.so
%{_libdir}/sane/libsane-agfafocus.so
%{_libdir}/sane/libsane-apple.so
%{_libdir}/sane/libsane-artec.so
%{_libdir}/sane/libsane-artec_eplus48u.so
%{_libdir}/sane/libsane-as6e.so
%{_libdir}/sane/libsane-avision.so
%{_libdir}/sane/libsane-bh.so
%{_libdir}/sane/libsane-canon.so
%{_libdir}/sane/libsane-canon630u.so
%{_libdir}/sane/libsane-canon_dr.so
%{_libdir}/sane/libsane-canon_lide70.so
%{_libdir}/sane/libsane-canon_pp.so
%{_libdir}/sane/libsane-cardscan.so
%{_libdir}/sane/libsane-coolscan.so
%{_libdir}/sane/libsane-coolscan2.so
%{_libdir}/sane/libsane-coolscan3.so
%{_libdir}/sane/libsane-dell1600n_net.so
%{_libdir}/sane/libsane-dll.so
%{_libdir}/sane/libsane-epjitsu.so
%{_libdir}/sane/libsane-epson.so
%{_libdir}/sane/libsane-epson2.so
%{_libdir}/sane/libsane-epsonds.so
%{_libdir}/sane/libsane-fujitsu.so
%{_libdir}/sane/libsane-genesys.so
%{_libdir}/sane/libsane-gt68xx.so
%{_libdir}/sane/libsane-hp.so
%{_libdir}/sane/libsane-hp3500.so
%{_libdir}/sane/libsane-hp3900.so
%{_libdir}/sane/libsane-hp4200.so
%{_libdir}/sane/libsane-hp5400.so
%{_libdir}/sane/libsane-hp5590.so
%{_libdir}/sane/libsane-hpljm1005.so
%{_libdir}/sane/libsane-hpsj5s.so
%{_libdir}/sane/libsane-hs2p.so
%{_libdir}/sane/libsane-ibm.so
%{_libdir}/sane/libsane-kodak.so
%{_libdir}/sane/libsane-kodakaio.so
%{_libdir}/sane/libsane-kvs1025.so
%{_libdir}/sane/libsane-kvs20xx.so
%{_libdir}/sane/libsane-kvs40xx.so
%{_libdir}/sane/libsane-leo.so
%{_libdir}/sane/libsane-lexmark.so
%{_libdir}/sane/libsane-ma1509.so
%{_libdir}/sane/libsane-magicolor.so
%{_libdir}/sane/libsane-matsushita.so
%{_libdir}/sane/libsane-microtek.so
%{_libdir}/sane/libsane-microtek2.so
%{_libdir}/sane/libsane-mustek.so
%{_libdir}/sane/libsane-mustek_pp.so
%{_libdir}/sane/libsane-mustek_usb.so
%{_libdir}/sane/libsane-mustek_usb2.so
%{_libdir}/sane/libsane-nec.so
%{_libdir}/sane/libsane-net.so
%{_libdir}/sane/libsane-niash.so
%{_libdir}/sane/libsane-p5.so
%{_libdir}/sane/libsane-pie.so
%{_libdir}/sane/libsane-pieusb.so
%{_libdir}/sane/libsane-pixma.so
%{_libdir}/sane/libsane-plustek.so
%{_libdir}/sane/libsane-plustek_pp.so
%{_libdir}/sane/libsane-ricoh.so
%{_libdir}/sane/libsane-ricoh2.so
%{_libdir}/sane/libsane-rts8891.so
%{_libdir}/sane/libsane-s9036.so
%{_libdir}/sane/libsane-sceptre.so
%{_libdir}/sane/libsane-sharp.so
%{_libdir}/sane/libsane-sm3600.so
%{_libdir}/sane/libsane-sm3840.so
%{_libdir}/sane/libsane-snapscan.so
%{_libdir}/sane/libsane-sp15c.so
%{_libdir}/sane/libsane-st400.so
%{_libdir}/sane/libsane-tamarack.so
%{_libdir}/sane/libsane-teco1.so
%{_libdir}/sane/libsane-teco2.so
%{_libdir}/sane/libsane-teco3.so
%{_libdir}/sane/libsane-test.so
%{_libdir}/sane/libsane-u12.so
%{_libdir}/sane/libsane-umax.so
%{_libdir}/sane/libsane-umax1220u.so
%{_libdir}/sane/libsane-umax_pp.so
%{_libdir}/sane/libsane-xerox_mfp.so
%{_libdir}/sane/*.so.1
%{_libdir}/sane/*.so.1.1.1
%exclude %{_libdir}/sane/*dc210.so*
%exclude %{_libdir}/sane/*dc240.so*
%exclude %{_libdir}/sane/*dc25.so*
%exclude %{_libdir}/sane/*dmc.so*
%exclude %{_libdir}/sane/*gphoto2.so*
%exclude %{_libdir}/sane/*qcam.so*
%exclude %{_libdir}/sane/*stv680.so*
%exclude %{_libdir}/sane/*v4l.so*


%files drivers-cameras
%{_libdir}/sane/libsane-dc210.so
%{_libdir}/sane/libsane-dc240.so
%{_libdir}/sane/libsane-dc25.so
%{_libdir}/sane/libsane-dmc.so
%{_libdir}/sane/libsane-gphoto2.so
%ifarch x86_64
%{_libdir}/sane/libsane-qcam.so
%endif
%{_libdir}/sane/libsane-stv680.so
%{_libdir}/sane/libsane-v4l.so
%{_libdir}/sane/*.so.1
%{_libdir}/sane/*.so.1.1.1


%files daemon
%config(noreplace) %{_sysconfdir}/sane.d/saned.conf
%{_sysusersdir}/sane-backends.conf
%{_sbindir}/saned
%{_udevrulesdir}/66-saned.rules
%{_unitdir}/saned.socket
%{_unitdir}/saned@.service
%{_mandir}/man8/saned*


%changelog
* Tue Aug 06 2024 Zhao Zhen <jeremiazhao@tencent.com> - 1.1.1-8
- fixed CVE-2023-46047 CVE-2023-46052

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.1-7
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 kianli <kianli@tencent.com> - 1.1.1-6
- Rebuilt for v4l-utils 1.24.1

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 1.1.1-5
- Rebuilt for libtiff 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.1-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 08 2023 rockerzhu <rockerzhu@tencent.com> - 1.1.1-2
- Disable bootstrap because sane-airscan is ready 

* Tue Mar 07 2023 rockerzhu <rockerzhu@tencent.com> - 1.1.1-1
- Initial build
